<?php
include_once('etc/vars.php');

// ******************************************************************
// AUTHOR FUNCTIONS
// Functions Available:
//  - getAuthorList
//    (Gets list of all authors.)
//  - getAuthor
//    (Provide author, will provide all author details.)
//  - getAuthorBookList
//    (Provide author, will tell what books are available)
//  - getAuthorOtherBookList
//    (Provide author, will tell what other books are available.)
//  - getAuthorCount
//    (Get a count of all the authors in the library.)
// ******************************************************************


// **** getAuthorList Function ****
// Input: Starting Record, Record Count
// Output: Author.Author_ID, Author.L_Name, Author.F_Name, Author.Extension
// Description: Gets list of all authors.
// Sorted By: Alphabetical Order
function getAuthorList($start = 0, $count = 100)
{
  global $dbPrefix;
  $queryString = 'SELECT author_id, l_name, f_name, ext
                  FROM `' . $dbPrefix . 'author`
                  ORDER BY l_name
                  LIMIT ' . $start . ',' . $count . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getAuthor Function ****
// Input: Author_ID
// Output: Author.Author_ID, Author.L_Name, Author.F_Name, Author.Extension
// Description: Provide author, will provide all author details.
function getAuthor($author_id)
{
  global $dbPrefix;
  $queryString = 'SELECT author_id, l_name, f_name, ext
                  FROM `' . $dbPrefix . 'author`
                  WHERE author_id = ' . $author_id . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getAuthorBookList Function ****
// Input: Author_ID
// Output: Book.Doc_id, Book.Title, Book.PublicationYear, Book.PostedDate
// Description: Provide author, will tell what books are available.
// Sorted By: Alphabetical Order (on Book Title)
function getAuthorBookList($author_id)
{
  global $dbPrefix;
  $queryString = 'SELECT b.doc_id, b.title, b.pub_year, b.posted
                  FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'author` AS a
                  WHERE b.author_id = a.author_id AND a.author_id = ' . $author_id . 
                  'ORDER BY b.title;';
  $result = dbQuery($queryString);
  return $result;
}

// **** getAuthorOtherBookList Function ****
// *******MIGHT BE BUGGY QUERY********
// Input: Doc_ID
// Output: Book.Doc_id, Book.Title, Book.PublicationYear, Book.PostedDate, Author.LastName, Author.FirstName
// Description: Provide author, will tell what other books are available.
// Sorted By: Alphabetical Order (on Book Title)
function getAuthorOtherBookList($doc_id)
{
  global $dbPrefix;
  $queryString = 'SELECT b1.doc_id, b1.title, b1.pub_year, b1.posted, a.l_name, a.f_name
                  FROM `' . $dbPrefix . 'book` AS b1
                   LEFT JOIN `' . $dbPrefix . 'author` AS a
                    ON b1.author_id = a.author_id
                   LEFT JOIN `' . $dbPrefix . 'book` AS b2
                    ON a.author_id = b2.author_id
                  WHERE b2.doc_id = ' . $doc_id . 
                  ' ORDER BY b1.title;';
  $result = dbQuery($queryString);
  return $result;
}

// **** getAuthorCount Function ****
// Input: --
// Output: Author.Count
// Description: Get a count of all the authors in the library.
function getAuthorCount()
{
  global $dbPrefix;
  $queryString = 'SELECT COUNT(author_id)
                  FROM `' . $dbPrefix . 'author`;';
  $result = dbQuery($queryString);
  return $result;
}
?>
