<?php
include_once('etc/vars.php');

// ******************************************************************
// BOOK FUNCTIONS
// Functions Available:
//  - getBookList
//    (Gets list of all books (with authors).)
//  - getBook
//    (Gets book info for a doc_id (with author).)
//  - getRecentBookList
//    (Return list of books published in the last X number of days.)
//  - getBookFormatList
//    (Specify book, will tell what formats book is available in.)
//  - getBookCount
//    (Get a count of all the books in the library (with optional modifier).)
// ******************************************************************

// **** getBookList Function ****
// Input: Row # to Start At, # of Rows to Retrieve & Author_ID, Category_ID, OR Format_ID (Optional Modifier)
// Output: Book.Doc_ID, Book.Title, Book, Alphabetical_Title, Author.Author_ID, Author.L_Name, Author.F_Name,
//         Author.Short_Name, Book.Pub_Year, Book.Posted
// Description: Gets list of all books (with authors).
// Sorted By: Alphabetical Order
function getBookList($start = 0, $count = 100, $author_id = NULL, $category_id = NULL, $format_id = NULL)
{
  global $dbPrefix;
  $queryString = 'SELECT b.doc_id, b.title, b.alpha_title, a.author_id, a.l_name, a.f_name, a.short_name, b.pub_year, b.posted
                   FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'author` AS a';

  if (!is_null($author_id))
  {
    $queryString .= ' WHERE a.author_id = ' . $author_id . ' AND ';
  }
  elseif (!is_null($category_id))
  {
    $queryString .= ', `' . $dbPrefix . 'bookcategory` AS bc
                      WHERE bc.doc_id = b.doc_id
                       AND bc.cat_id = ' . $category_id . ' AND ';
  }
  elseif (!is_null($format_id))
  {
    $queryString .= ', `' . $dbPrefix . 'format` AS bf
                      WHERE bf.doc_id = b.doc_id
                       AND bf.format_id = ' . $format_id . ' AND ';
  }
  else
  {
    $queryString .= ' WHERE ';
  }

  $queryString .= ' b.author_id = a.author_id
                   ORDER BY b.alpha_title, b.title
                   LIMIT ' . $start . ',' . $count . ';';

  $result = dbQuery($queryString);
  return $result;
}


// **** getBook Function ****
// Input: Book.Doc_ID
// Output: Book.Title, Author.L_Name, Author.F_Name, Book.Pub_Year, Book.Posted
// Description: Gets book info for a particular document ID (with author).
// Sorted By: none
function getBook($doc_id)
{
  global $dbPrefix;
  $queryString = 'SELECT b.title, a.author_id, a.l_name, a.f_name, b.pub_year, b.posted
                  FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'author` AS a
                  WHERE b.author_id = a.author_id
                   AND b.doc_id = ' . $doc_id . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getRecentBookList Function ****
// Input: Days And/Or Books
// Output: Book.Doc_ID, Book.Title, Author.L_Name, Author.F_Name, Book.Pub_Year, Book.Posted
// Description: Specify a number of days and/or number of books, it will return list of books published in that period (Now - days).
// Sorted By: Chronological Order (Most Recent Date First)
function getRecentBookList($days = 1000, $books = 10)
{
  global $dbPrefix;
  $queryString = 'SELECT b.doc_id, b.title, a.l_name, a.f_name, b.pub_year, b.posted
                  FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'author` AS a
                  WHERE b.author_id = a.author_id
                   AND DATE_SUB(CURDATE(), INTERVAL ' . $days . ' DAY) <= b.posted
                  ORDER BY b.posted DESC
                  LIMIT 0, ' . $books . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getBookFormatList Function ****
// Input: Doc_ID
// Output: Format.Extension, Format.Description
// Description: Specify book, will tell what formats book is available in.
// Sorted By: Order in Format Table.
function getBookFormatList($doc_id)
{
  global $dbPrefix;
  $queryString = 'SELECT f.extension, f.description
                  FROM `' . $dbPrefix . 'bookformat` AS bf , `' . $dbPrefix . 'format` AS f
                  WHERE bf.format_id = f.format_id AND bf.doc_id = ' . $doc_id . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getBookCount Function ****
// Input: Author_ID OR Category_ID OR Format_ID
// Output: Book.Count
// Description: Get a count of all the books in the library (with optional modifier)
function getBookCount($author_id = NULL, $category_id = NULL, $format_id = NULL)
{
  global $dbPrefix;
  if (!is_null($author_id))
  {
    $queryString = 'SELECT COUNT(b.doc_id)
                    FROM `' . $dbPrefix . 'book` AS b
                    WHERE author_id = ' . $author_id . ';';
  }
  elseif (!is_null($category_id))
  {
    $queryString = 'SELECT COUNT(b.doc_id)
                    FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'bookcategory` as bc
                    WHERE b.doc_id = bc.doc_id
                     AND bc.cat_id = ' . $category_id . ';';
  }
  elseif (!is_null($format_id))
  {
    $queryString = 'SELECT COUNT(b.doc_id)
                    FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'bookformat` as bf
                    WHERE b.doc_id = bf.doc_id
                     AND bf.format_id = ' . $format_id . ';';
  }
  else
  {
    $queryString = 'SELECT COUNT(b.doc_id)
                    FROM `' . $dbPrefix . 'book` AS b;';
  }
  $result = dbQuery($queryString);
  return $result;
}
?>