<?php
include_once('etc/vars.php');

// ******************************************************************
// FORMAT FUNCTIONS
// Functions Available:
//  - getFormatList
//    (Gets list of all formats.)
//  - getFormat
//    (Gets details of a particular format ID.)
//  - getFormatBookList
//    (Gets list of all books (with authors) available in a particular format.)
//  - getBookFormatDetails
//    (Gets the format details of a passed in format extension.)
// ******************************************************************

// **** getFormatList Function ****
// Input: --
// Output: Format.Format_ID, Format.Extension, Format.Description
// Description: Gets list of all formats.
// Sorted By: Alphabetical Order (on Extension)
function getFormatList()
{
  global $dbPrefix;
  $queryString = 'SELECT format_id, extension, description
                  FROM `' . $dbPrefix . 'format`
                  ORDER BY extension;';
  $result = dbQuery($queryString);
  return $result;
}


// **** getFormat Function ****
// Input: Format_ID
// Output: Format.Format_ID, Format.Extension, Format.Description
// Description: Gets details of a particular format ID.
function getFormat($format_id)
{
  global $dbPrefix;
  $queryString = 'SELECT format_id, extension, description
                  FROM `' . $dbPrefix . 'format`
                  WHERE format_id = ' . $format_id . ';';
  $result = dbQuery($queryString);
  return $result;
}


// **** getFormatBookList Function ****
// Input: Format_ID
// Output: Book.Doc_ID, Book.Title, Author.L_Name, Author.F_Name, Book.Pub_Year, Book.Posted
// Description: Gets list of all books (with authors) available in a particular format.
// Sorted By: Alphabetical Order (on Book Title)
function getFormatBookList($format_id)
{
  global $dbPrefix;
  $queryString = 'SELECT b.doc_id, b.title, a.l_name, a.f_name, b.pub_year, b.posted
                  FROM `' . $dbPrefix . 'book` AS b, `' . $dbPrefix . 'author` AS a, `' . $dbPrefix . 'bookformat` bf
                  WHERE b.author_id = a.author_id
                   AND b.doc_id = bf.doc_id
                   AND bf.format_id = ' . $format_id . 
                  ' ORDER BY b.title;';
  $result = dbQuery($queryString);
  return $result;
}


// **** getBookFormatDetails Function ****
// Input: Format Extension
// Output: Format.SourcePath, Format.XsltFile, Format.HeaderFile, Format.FooterFile
// Description: Gets the format details of a passed in format extension.
// Sorted By: Alphabetical Order (on Book Title)
function getBookFormatDetails($ext)
{
  global $dbPrefix;
  $queryString = 'SELECT sourcepath, xsltfile, headerfile, footerfile
                  FROM `' . $dbPrefix . 'format`
                  WHERE extension = \'' . $ext . '\';';
  $result = dbQuery($queryString);
  return $result;
}
?>
