<?php
include_once('etc/vars.php');

// ******************************************************************
// MISCELLANEOUS FUNCTIONS
// Functions Available:
//  - validateNumericGetVariable
//    (Validates numeric GET variables.)
//  - getPageTitleValue
//    (Generates proper <title> tag.)
//  - getBibleBook
//    (Change the format the Bible book is represented in.)
// ******************************************************************

// **** validateNumericGetVariable Function ****
// Input: Variable (Numeric, NULL, or other)
// Output: Numeric variable.
// Description: Validates GET variables, and returns 0 if not a valid positive number.
function validateNumericGetVariable($variable)
{
  // Invalid, none, or negative rowStart value
  if (!is_numeric($variable) || $variable < 0) 
  {
    $variable = 0;
  }
  return $variable;
}



// **** getPageTitleValue Function ****
// Input: ID, Author, Category, OR Format boolean (what type of ID it is)
// Output: PageTitle string
// Description: Gathers the proper page title from the DB, for the <title> tag.
function getPageTitleValue($id, $author = FALSE, $category = FALSE, $format = FALSE)
{
  global $siteName;
  
  if ($author == TRUE)
  {
    if ($id != 0)
    {
      $authors = getAuthor($id);
      if (!$authors == '')
      {
        if ($author = dbGetRow($authors))
          $pageTitle = 'Author: ' . $author[2] . ' ' . $author[1] . ' ' . $author[3];
        else
         $id = 0;
      }
      else
        $id = 0;
    }
    
    if ($id == 0)
    { 
      $pageTitle = 'Author Listing';
    }
  }
  elseif ($category == TRUE)
  {
    if ($id != 0)
    {
      $categories = getCategory($id);
      if (!$categories == '')
      {
        if ($category = dbGetRow($categories))
          $pageTitle = 'Topical Listing: ' . $category[1];
        else
          $id = 0;
      }
      else
        $id = 0;
    }
    
    if ($id == 0)
    { 
      $pageTitle = 'Topic Listing';
    }
  }
  elseif ($format == TRUE)
  {
    if ($id != 0)
    {
      $formats = getFormat($id);
      if (!$formats == '')
      {
        if ($format = dbGetRow($formats))
          $pageTitle = 'Listing of ' . $format[2] . ' Books';
        else
          $id = 0;
      }
      else
        $id = 0;
    }
    
    if ($id == 0)
    { 
      $pageTitle = 'Format Listing';
    }
  }
  else
  {
    if ($id != 0)
    {
      $books = getBook($id);
      if (!$books == '')
      {
        if ($book = dbGetRow($books))
          $pageTitle = $book[0] . ' - ' . $book[3] . ' ' . $book[2];
        else
          $id = 0;
      }
      else
        $id = 0;
    }
    
    if ($id == 0)
    { 
      $pageTitle = 'Book Listing';
    }
  }
  
  return $pageTitle;
}


// **** getBibleBook Function ****
// Input: Value, Original Format, Desired Format
// Output: Desired Format String of Bible Book
// Description: Returns a bible book value relating to what you inputted.
//              Three Format Types: 'number', 'parsed', 'proper'
//                All can be from or to.
//              Used for converting to proper format.  Stored as Numbers in DB, Parsed in XML.
function getBibleBook($value, $from_format = 'number', $to_format = 'proper')
{
  $books = array(
    1 =>  'Genesis','Exodus','Leviticus','Numbers','Deuteronomy','Joshua','Judges','Ruth','1 Samuel','2 Samuel','1 Kings','2 Kings','1 Chronicles','2 Chronicles',
          'Ezra','Nehemiah','Esther','Job','Psalms','Proverbs','Ecclesiastes','Song of Solomon','Isaiah','Jeremiah','Lamentations','Ezekiel','Daniel','Hosea',
          'Joel','Amos','Obadiah','Jonah','Micah','Nahum','Habakkuk','Zephaniah','Haggai','Zechariah','Malachi','Matthew','Mark','Luke','John','Acts','Romans',
          '1 Corinthians','2 Corinthians','Galatians','Ephesians','Philippians','Colossians','1 Thessalonians','2 Thessalonians','1 Timothy','2 Timothy','Titus',
          'Philemon','Hebrews','James','1 Peter','2 Peter','1 John','2 John','3 John','Jude','Revelation');

  $parsedbooks = array(
    1 =>  'Genesis','Exodus','Leviticus','Numbers','Deuteronomy','Joshua','Judges','Ruth','1Samuel','2Samuel','1Kings','2Kings','1Chronicles','2Chronicles',
          'Ezra','Nehemiah','Esther','Job','Psalms','Proverbs','Ecclesiastes','SongofSolomon','Isaiah','Jeremiah','Lamentations','Ezekiel','Daniel','Hosea',
          'Joel','Amos','Obadiah','Jonah','Micah','Nahum','Habakkuk','Zephaniah','Haggai','Zechariah','Malachi','Matthew','Mark','Luke','John','Acts','Romans',
          '1Corinthians','2Corinthians','Galatians','Ephesians','Philippians','Colossians','1Thessalonians','2Thessalonians','1Timothy','2Timothy','Titus',
          'Philemon','Hebrews','James','1Peter','2Peter','1John','2John','3John','Jude','Revelation');
  
  switch ($from_format)
  {
      case 'number':
          if ($to_format == 'proper')
            $return_value = $books[$value];
          elseif ($to_format == 'parsed')
            $return_value = $parsedbooks[$value];
          elseif ($to_format == 'number')
            $return_value = $value;
          break;
      case 'proper':
          if ($to_format == 'proper')
            $return_value = $value;
          elseif ($to_format == 'parsed')
            $return_value = $parsedbooks[array_search($value, $books)];
          elseif ($to_format == 'number')
            $return_value = array_search($value, $books);
          break;
      case 'parsed':
          if ($to_format == 'proper')
            $return_value = $books[array_search($value, $parsedbooks)];
          elseif ($to_format == 'parsed')
            $return_value = $value;
          elseif ($to_format == 'number')
            $return_value = array_search($value, $parsedbooks);
          break;
  }
  return $return_value;
}


/*  UNNEEDED AT THIS POINT
// **** blockGetQuoteOfDay Function ****
// Input: --
// Output: Floating div with list of the author's other books.
// Description: Gets list of all other books of the author.
// Sorted By: Alphabetical Order
function blockGetQuoteOfDay()
{
  global $dbPrefix;
  $today = getdate();
  $dayofyear = $today['yday'];
  $dayofyear = 1; //Remove once table is populated.
  if ($dayofyear > 0)
  {
    $queryString = 'SELECT quote, author, context, source, doc_id
                    FROM `' . $dbPrefix . 'quote`
                    WHERE quote_id = ' . $dayofyear . ';';
    $quote = dbQuery($queryString);
  
    if (!$quote == '')
    {
      if ($quote = dbGetRow($quote))
      {
        print '<div class="sidebartitle">Quote of the Day</div>';
        print '<div class="sidebaritems">' . $quote[0];
        print '<br /><span style="text-align: right"> - <i><b>' . $quote[1] . '</b></i> in ' . $quote[3];
        print '<br />(' . $quote[2] . ')</span>';
        print '</div>';
      }
    }
  }
}
*/


?>